@@ -7,7 +7,6 @@ import six
 from apscheduler.job import Job
 from apscheduler.schedulers.base import BaseScheduler
 from apscheduler.triggers.date import DateTrigger
-from tests.conftest import maxpython
 
 try:
     from unittest.mock import MagicMock, patch
@@ -253,17 +252,24 @@ def test_repr(job):
         assert repr(job) == b'<Job (id=t\xc3\xa9st\xc3\xafd name=n\xc3\xa4m\xc3\xa9)>'.decode('utf-8')
 
 
-def test_str(job):
-    if six.PY2:
-        expected = 'n\\xe4m\\xe9 (trigger: date[2011-04-03 18:40:00 CEST], next run at: None)'
+@pytest.mark.parametrize('status, expected_status', [
+    ('scheduled', 'next run at: 2011-04-03 18:40:00 CEST'),
+    ('paused', 'paused'),
+    ('pending', 'pending')
+], ids=['scheduled', 'paused', 'pending'])
+@pytest.mark.parametrize('unicode', [False, True], ids=['nativestr', 'unicode'])
+def test_str(create_job, status, unicode, expected_status):
+    job = create_job(func=dummyfunc)
+    if status == 'scheduled':
+        job.next_run_time = job.trigger.run_date
+    elif status == 'pending':
+        del job.next_run_time
+
+    if six.PY2 and not unicode:
+        expected = 'n\\xe4m\\xe9 (trigger: date[2011-04-03 18:40:00 CEST], %s)' % expected_status
     else:
-        expected = b'n\xc3\xa4m\xc3\xa9 (trigger: date[2011-04-03 18:40:00 CEST], next run at: None)'.\
-            decode('utf-8')
+        expected = b'n\xc3\xa4m\xc3\xa9 (trigger: date[2011-04-03 18:40:00 CEST], %s)'.\
+            decode('utf-8') % expected_status
 
-    assert str(job) == expected
-
-
-@maxpython(3, 0)
-def test_unicode(job):
-    assert job.__unicode__() == \
-        b'n\xc3\xa4m\xc3\xa9 (trigger: date[2011-04-03 18:40:00 CEST], next run at: None)'.decode('utf-8')
+    result = job.__unicode__() if unicode else job.__str__()
+    assert result == expected
